/*
 * This file is part of vospace-file-service
 * Copyright (C) 2021 Istituto Nazionale di Astrofisica
 * SPDX-License-Identifier: GPL-3.0-or-later
 */
package it.inaf.ia2.transfer.controller;

import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.beans.factory.annotation.Autowired;
import it.inaf.ia2.transfer.service.FileCopyService;
import java.util.concurrent.CompletableFuture;

@RestController
public class CopyController extends AuthenticatedFileController {

    @Autowired
    private FileCopyService copyService;

    @PostMapping(value = "/copy", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<?> copyFiles(@RequestBody CopyRequest copyRequest) {
               
        // need to make a completable future start
        CompletableFuture.runAsync(() -> {
            handleFileJob(() -> copyService.copyFiles(copyRequest.getSourceRootVosPath(), 
                copyRequest.getDestinationRootVosPath(), copyRequest.getJobId(), 
                getPrincipal()), copyRequest.jobId);
        });     

        return ResponseEntity.ok(
                copyRequest.getJobId() + " copy task accepted by File Service"
        );        
        
        
    }

    @Override
    protected String getCustomAuthErrorMessage() {
        return "File Copy not allowed to anonymous users";
    }

}
